==> gcli-2.1.0.tar.gz: gcli-2.1.0/include/gcli/cmd/pipelines.h <==
/*
 * Copyright 2023 Nico Sonack <nsonack@herrhotzenplotz.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef GCLI_CMD_PIPELINES_H
#define GCLI_CMD_PIPELINES_H

#include <gcli/gcli.h>

#include <gcli/gitlab/pipelines.h>

void gitlab_print_pipelines(gitlab_pipeline_list const *const list);
int gitlab_pipelines(char const *owner, char const *repo, int const count);

int gitlab_mr_pipelines(char const *owner, char const *repo, int const mr_id);

int gitlab_pipeline_jobs(char const *owner, char const *repo, long pipeline,
                         int count);
void gitlab_print_jobs(gitlab_job_list const *const list);

void gitlab_print_job_status(gitlab_job const *const job);
int gitlab_job_status(char const *owner, char const *repo, long const jid);

int subcommand_pipelines(int argc, char *argv[]);

#endif /* GCLI_CMD_PIPELINES_H */

==> gcli_2.3.0.orig.tar.gz: gcli-2.3.0/include/gcli/cmd/pipelines.h <==
/*
 * Copyright 2023 Nico Sonack <nsonack@herrhotzenplotz.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef GCLI_CMD_PIPELINES_H
#define GCLI_CMD_PIPELINES_H

#include <gcli/gcli.h>

#include <gcli/gitlab/pipelines.h>

void gitlab_print_pipelines(struct gitlab_pipeline_list const *const list);
int gitlab_pipelines(char const *owner, char const *repo, int const count);

int gitlab_mr_pipelines(char const *owner, char const *repo, int const mr_id);

int gitlab_pipeline_jobs(char const *owner, char const *repo, long pipeline,
                         int count);
void gitlab_print_jobs(struct gitlab_job_list const *const list);

void gitlab_print_job_status(struct gitlab_job const *const job);
int gitlab_job_status(char const *owner, char const *repo, long const jid);

int subcommand_pipelines(int argc, char *argv[]);

#endif /* GCLI_CMD_PIPELINES_H */
